@@ -39,7 +39,7 @@ namespace KBlog {
     class WordpressBuggyPrivate;
 /**
   @brief
-  A class that can be used for access to blogs (Wordpress < 2.4, Drupal <= 5.5
+  A class that can be used for access to blogs (Wordpress, Drupal <5.6
   and most likely many more) which simply use the yyyyMMddThh:mm:ss
   dateTime.iso8601 format stated on http://www.xmlrpc.com. This is only an example for
   an ISO-8601 compatible format, but many blogs seem to assume exactly this format.
@@ -56,6 +56,7 @@ namespace KBlog {
   Blog* myblog = new WordpressBuggy("http://example.com/xmlrpc/gateway.php");
   myblog->setUsername( "some_user_id" );
   myblog->setPassword( "YoURFunnyPAsSwoRD" );
+  myblog->setBlogId( "1" ); // can be caught by listBlogs()
   KBlog::BlogPost *post = new BlogPost();
   post->setTitle( "This is the title." );
   post->setContent( "Here is some the content..." );
