@@ -457,8 +457,8 @@ Incidence *Calendar::dissociateOccurrence( Incidence *incidence,
     if ( duration > 0 ) {
       int doneduration = recur->durationTo( date.addDays( -1 ) );
       if ( doneduration >= duration ) {
-        kDebug(5800) << "The dissociated event already occurred more often"
-                     << "than it was supposed to ever occur. ERROR!";
+        kDebug() << "The dissociated event already occurred more often"
+                 << "than it was supposed to ever occur. ERROR!";
         recur->clear();
       } else {
         recur->setDuration( duration - doneduration );
@@ -817,7 +817,7 @@ void Calendar::setupRelations( Incidence *forincidence )
 void Calendar::removeRelations( Incidence *incidence )
 {
   if ( !incidence ) {
-    kDebug(5800) << "Warning: Calendar::removeRelations( 0 )!\n";
+    kDebug() << "Warning: incidence is 0";
     return;
   }
 
@@ -1050,9 +1050,7 @@ void Calendar::appendAlarms( Alarm::List &alarms, Incidence *incidence,
     if ( alarmlist[i]->enabled() ) {
       KDateTime dt = alarmlist[i]->nextRepetition( preTime );
       if ( dt.isValid() && dt <= to ) {
-        kDebug(5800) << "Calendar::appendAlarms() '"
-                     << incidence->summary() << "':"
-                     << dt.toString();
+        kDebug() << incidence->summary() << "':" << dt.toString();
         alarms.append( alarmlist[i] );
       }
     }
@@ -1166,8 +1164,7 @@ void Calendar::appendRecurringAlarms( Alarm::List &alarms,
           }
         }
       }
-      kDebug(5800) << "Calendar::appendAlarms() '" << incidence->summary()
-                   << "':" << dt.toString();
+      kDebug() << incidence->summary() << "':" << dt.toString();
       alarms.append( a );
     }
   }
