@@ -101,6 +101,11 @@ ResourceCachedReloadConfig::ResourceCachedReloadConfig( QWidget *parent )
   groupBox->setLayout(vbox);
 }
 
+ResourceCachedReloadConfig::~ResourceCachedReloadConfig()
+{
+   delete d;
+}
+
 void ResourceCachedReloadConfig::loadSettings( ResourceCached *resource )
 {
   d->mGroup->button( resource->reloadPolicy() )->setChecked( true );
@@ -163,8 +168,8 @@ ResourceCachedSaveConfig::ResourceCachedSaveConfig( QWidget *parent )
     new QRadioButton(
       i18nc( "@option:radio save the cache after every modification",
              "On every change" ), groupBox );
-  d->mGroup->addButton(delay,3);
-  d->mGroup->addButton(every,4);
+  d->mGroup->addButton( delay, 3 );
+  d->mGroup->addButton( every, 4 );
 
   QVBoxLayout *vbox = new QVBoxLayout;
   vbox->addWidget(never);
@@ -178,6 +183,11 @@ ResourceCachedSaveConfig::ResourceCachedSaveConfig( QWidget *parent )
 
 }
 
+ResourceCachedSaveConfig::~ResourceCachedSaveConfig()
+{
+  delete d;
+}
+
 void ResourceCachedSaveConfig::loadSettings( ResourceCached *resource )
 {
   d->mGroup->button( resource->savePolicy() )->setChecked( true );
