@@ -165,7 +165,7 @@ void IdMapper::removeRemoteId( const QString &remoteId )
   QMap<QString, QVariant>::Iterator it;
   for ( it = d->idMap.begin(); it != d->idMap.end(); ++it ) {
     if ( it.value().toString() == remoteId ) {
-      d->idMap.erase( it );
+      d->idMap.remove( it.key() );
       d->fingerprintMap.remove( it.key() );
       return;
     }
