@@ -27,7 +27,7 @@
 using namespace MailTransport;
 
 K_PLUGIN_FACTORY( MailTransportConfigFactory, registerPlugin<ConfigModule>(); )
-K_EXPORT_PLUGIN( MailTransportConfigFactory( "mailtrasnport" ) )
+K_EXPORT_PLUGIN( MailTransportConfigFactory( "mailtransport" ) )
 
 ConfigModule::ConfigModule( QWidget * parent, const QVariantList & args ) :
     KCModule( MailTransportConfigFactory::componentData(), parent, args )
