@@ -1,7 +1,7 @@
 /*
  * This file is part of the syndication library
  *
- * Copyright (C) 2006 Frank Osterfeld <frank.osterfeld@kdemail.net>
+ * Copyright (C) 2006 Frank Osterfeld <osterfeld@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -20,8 +20,8 @@
  *
  */
 
-#include "categoryatomimpl.h"
 #include "feedatomimpl.h"
+#include "categoryatomimpl.h"
 #include "imageatomimpl.h"
 #include "itematomimpl.h"
 #include <personimpl.h>
@@ -30,10 +30,10 @@
 #include <atom/link.h>
 #include <atom/person.h>
 
-#include <QDomElement>
-#include <QList>
-#include <QMultiMap>
-#include <QString>
+#include <QtXml/QDomElement>
+#include <QtCore/QList>
+#include <QtCore/QMultiMap>
+#include <QtCore/QString>
 
 namespace Syndication {
 
